==> lxqt-config-0.17.1.tar.xz: lxqt-config-0.17.1/lxqt-config-locale/translations/lxqt-config-locale_oc.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="oc">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation>Re&amp;gion :</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation>De&amp;tals dels reglatges</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Nombres :</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation>&amp;Ora :</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Devisa :</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Unitats de mesura :</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>&amp;Tria e règlas de classament :</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation>&lt;b&gt;Exemples&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation>Nombres :</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation>Ora :</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation>Devisa :</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation>Unitats de mesura :</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="127"/>
        <source>No change</source>
        <translation>Cap de cambiament</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="316"/>
        <source>Format Settings Changed</source>
        <translation>Paramètres del format modificats</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="317"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Volètz enregistrar las modificacions ? S’aplicaràn a la connexion venenta.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="438"/>
        <source>Imperial UK</source>
        <translation>Imperial Reialme-Unit</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="442"/>
        <source>Imperial US</source>
        <translation>Imperial Estats-Units</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="446"/>
        <source>Metric</source>
        <translation>Metric</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>LXQt Locale Configuration</source>
        <translation>Paramètres regionals de LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Locale Settings</source>
        <translation>Paramètres regionals</translation>
    </message>
</context>
</TS>

==> lxqt-config-1.0.0.tar.xz: lxqt-config-1.0.0/lxqt-config-locale/translations/lxqt-config-locale_oc.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="oc">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation>Re&amp;gion&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation>De&amp;tals dels reglatges</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Nombres&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation>&amp;Ora&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Devisa&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Unitats de mesura&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>&amp;Tria e règlas de classament&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation>&lt;b&gt;Exemples&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation>Nombres&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation>Ora&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation>Devisa&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation>Unitats de mesura&#x202f;:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="127"/>
        <source>No change</source>
        <translation>Cap de cambiament</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="316"/>
        <source>Format Settings Changed</source>
        <translation>Paramètres del format modificats</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="317"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Volètz enregistrar las modificacions&#x202f;? S’aplicaràn a la connexion venenta.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="438"/>
        <source>Imperial UK</source>
        <translation>Imperial Reialme-Unit</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="442"/>
        <source>Imperial US</source>
        <translation>Imperial Estats-Units</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="446"/>
        <source>Metric</source>
        <translation>Metric</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>LXQt Locale Configuration</source>
        <translation>Paramètres regionals de LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Locale Settings</source>
        <translation>Paramètres regionals</translation>
    </message>
</context>
</TS>
